==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/FacilityConditionIndex.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.REGIONID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTOFNEEDEDREPAIRS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REPLACEMENTVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FACILITYCONDITIONINDEX" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UTILITYBILLLEVEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GASTRACKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOORAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOORAREAUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDREVENUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REGION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REGIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIMARYUSE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}YEARBUILT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICELIFE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYSTARELIGIBLE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "costofneededrepairs",
    "replacementvalue",
    "facilityconditionindex",
    "utilitybilllevel",
    "gastracked",
    "floorarea",
    "floorareauom",
    "estimatedrevenue",
    "region",
    "regionid",
    "primaryuse",
    "yearbuilt",
    "servicelife",
    "energystareligible"
})
@XmlRootElement(name = "FacilityConditionIndex")
public class FacilityConditionIndex {

    @XmlElement(name = "COSTOFNEEDEDREPAIRS", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT costofneededrepairs;
    @XmlElement(name = "REPLACEMENTVALUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT replacementvalue;
    @XmlElement(name = "FACILITYCONDITIONINDEX", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT facilityconditionindex;
    @XmlElement(name = "UTILITYBILLLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String utilitybilllevel;
    @XmlElement(name = "GASTRACKED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String gastracked;
    @XmlElement(name = "FLOORAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY floorarea;
    @XmlElement(name = "FLOORAREAUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type floorareauom;
    @XmlElement(name = "ESTIMATEDREVENUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedrevenue;
    @XmlElement(name = "REGION", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type region;
    @XmlElement(name = "REGIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected REGIONID_Type regionid;
    @XmlElement(name = "PRIMARYUSE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type primaryuse;
    @XmlElement(name = "YEARBUILT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY yearbuilt;
    @XmlElement(name = "SERVICELIFE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY servicelife;
    @XmlElement(name = "ENERGYSTARELIGIBLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String energystareligible;

    /**
     * Obtient la valeur de la propriété costofneededrepairs.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getCOSTOFNEEDEDREPAIRS() {
        return costofneededrepairs;
    }

    /**
     * Définit la valeur de la propriété costofneededrepairs.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setCOSTOFNEEDEDREPAIRS(AMOUNT value) {
        this.costofneededrepairs = value;
    }

    /**
     * Obtient la valeur de la propriété replacementvalue.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getREPLACEMENTVALUE() {
        return replacementvalue;
    }

    /**
     * Définit la valeur de la propriété replacementvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setREPLACEMENTVALUE(AMOUNT value) {
        this.replacementvalue = value;
    }

    /**
     * Obtient la valeur de la propriété facilityconditionindex.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getFACILITYCONDITIONINDEX() {
        return facilityconditionindex;
    }

    /**
     * Définit la valeur de la propriété facilityconditionindex.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setFACILITYCONDITIONINDEX(AMOUNT value) {
        this.facilityconditionindex = value;
    }

    /**
     * Obtient la valeur de la propriété utilitybilllevel.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUTILITYBILLLEVEL() {
        return utilitybilllevel;
    }

    /**
     * Définit la valeur de la propriété utilitybilllevel.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUTILITYBILLLEVEL(String value) {
        this.utilitybilllevel = value;
    }

    /**
     * Obtient la valeur de la propriété gastracked.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGASTRACKED() {
        return gastracked;
    }

    /**
     * Définit la valeur de la propriété gastracked.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGASTRACKED(String value) {
        this.gastracked = value;
    }

    /**
     * Obtient la valeur de la propriété floorarea.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFLOORAREA() {
        return floorarea;
    }

    /**
     * Définit la valeur de la propriété floorarea.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFLOORAREA(QUANTITY value) {
        this.floorarea = value;
    }

    /**
     * Obtient la valeur de la propriété floorareauom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getFLOORAREAUOM() {
        return floorareauom;
    }

    /**
     * Définit la valeur de la propriété floorareauom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setFLOORAREAUOM(UOMID_Type value) {
        this.floorareauom = value;
    }

    /**
     * Obtient la valeur de la propriété estimatedrevenue.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDREVENUE() {
        return estimatedrevenue;
    }

    /**
     * Définit la valeur de la propriété estimatedrevenue.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDREVENUE(AMOUNT value) {
        this.estimatedrevenue = value;
    }

    /**
     * Obtient la valeur de la propriété region.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getREGION() {
        return region;
    }

    /**
     * Définit la valeur de la propriété region.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setREGION(TYPE_Type value) {
        this.region = value;
    }

    /**
     * Obtient la valeur de la propriété regionid.
     * 
     * @return
     *     possible object is
     *     {@link REGIONID_Type }
     *     
     */
    public REGIONID_Type getREGIONID() {
        return regionid;
    }

    /**
     * Définit la valeur de la propriété regionid.
     * 
     * @param value
     *     allowed object is
     *     {@link REGIONID_Type }
     *     
     */
    public void setREGIONID(REGIONID_Type value) {
        this.regionid = value;
    }

    /**
     * Obtient la valeur de la propriété primaryuse.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getPRIMARYUSE() {
        return primaryuse;
    }

    /**
     * Définit la valeur de la propriété primaryuse.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setPRIMARYUSE(TYPE_Type value) {
        this.primaryuse = value;
    }

    /**
     * Obtient la valeur de la propriété yearbuilt.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getYEARBUILT() {
        return yearbuilt;
    }

    /**
     * Définit la valeur de la propriété yearbuilt.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setYEARBUILT(QUANTITY value) {
        this.yearbuilt = value;
    }

    /**
     * Obtient la valeur de la propriété servicelife.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSERVICELIFE() {
        return servicelife;
    }

    /**
     * Définit la valeur de la propriété servicelife.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSERVICELIFE(QUANTITY value) {
        this.servicelife = value;
    }

    /**
     * Obtient la valeur de la propriété energystareligible.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYSTARELIGIBLE() {
        return energystareligible;
    }

    /**
     * Définit la valeur de la propriété energystareligible.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYSTARELIGIBLE(String value) {
        this.energystareligible = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/FacilityConditionIndex.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.REGIONID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COSTOFNEEDEDREPAIRS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REPLACEMENTVALUE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FACILITYCONDITIONINDEX" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UTILITYBILLLEVEL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}GASTRACKED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FLOORAREA" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FLOORAREAUOM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDREVENUE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REGION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REGIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRIMARYUSE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}YEARBUILT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SERVICELIFE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ENERGYSTARELIGIBLE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "costofneededrepairs",
    "replacementvalue",
    "facilityconditionindex",
    "utilitybilllevel",
    "gastracked",
    "floorarea",
    "floorareauom",
    "estimatedrevenue",
    "region",
    "regionid",
    "primaryuse",
    "yearbuilt",
    "servicelife",
    "energystareligible"
})
@XmlRootElement(name = "FacilityConditionIndex")
public class FacilityConditionIndex {

    @XmlElement(name = "COSTOFNEEDEDREPAIRS", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT costofneededrepairs;
    @XmlElement(name = "REPLACEMENTVALUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT replacementvalue;
    @XmlElement(name = "FACILITYCONDITIONINDEX", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT facilityconditionindex;
    @XmlElement(name = "UTILITYBILLLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String utilitybilllevel;
    @XmlElement(name = "GASTRACKED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String gastracked;
    @XmlElement(name = "FLOORAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY floorarea;
    @XmlElement(name = "FLOORAREAUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type floorareauom;
    @XmlElement(name = "ESTIMATEDREVENUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedrevenue;
    @XmlElement(name = "REGION", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type region;
    @XmlElement(name = "REGIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected REGIONID_Type regionid;
    @XmlElement(name = "PRIMARYUSE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type primaryuse;
    @XmlElement(name = "YEARBUILT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY yearbuilt;
    @XmlElement(name = "SERVICELIFE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY servicelife;
    @XmlElement(name = "ENERGYSTARELIGIBLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String energystareligible;

    /**
     * Gets the value of the costofneededrepairs property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getCOSTOFNEEDEDREPAIRS() {
        return costofneededrepairs;
    }

    /**
     * Sets the value of the costofneededrepairs property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setCOSTOFNEEDEDREPAIRS(AMOUNT value) {
        this.costofneededrepairs = value;
    }

    /**
     * Gets the value of the replacementvalue property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getREPLACEMENTVALUE() {
        return replacementvalue;
    }

    /**
     * Sets the value of the replacementvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setREPLACEMENTVALUE(AMOUNT value) {
        this.replacementvalue = value;
    }

    /**
     * Gets the value of the facilityconditionindex property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getFACILITYCONDITIONINDEX() {
        return facilityconditionindex;
    }

    /**
     * Sets the value of the facilityconditionindex property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setFACILITYCONDITIONINDEX(AMOUNT value) {
        this.facilityconditionindex = value;
    }

    /**
     * Gets the value of the utilitybilllevel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUTILITYBILLLEVEL() {
        return utilitybilllevel;
    }

    /**
     * Sets the value of the utilitybilllevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUTILITYBILLLEVEL(String value) {
        this.utilitybilllevel = value;
    }

    /**
     * Gets the value of the gastracked property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGASTRACKED() {
        return gastracked;
    }

    /**
     * Sets the value of the gastracked property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGASTRACKED(String value) {
        this.gastracked = value;
    }

    /**
     * Gets the value of the floorarea property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFLOORAREA() {
        return floorarea;
    }

    /**
     * Sets the value of the floorarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFLOORAREA(QUANTITY value) {
        this.floorarea = value;
    }

    /**
     * Gets the value of the floorareauom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getFLOORAREAUOM() {
        return floorareauom;
    }

    /**
     * Sets the value of the floorareauom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setFLOORAREAUOM(UOMID_Type value) {
        this.floorareauom = value;
    }

    /**
     * Gets the value of the estimatedrevenue property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDREVENUE() {
        return estimatedrevenue;
    }

    /**
     * Sets the value of the estimatedrevenue property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDREVENUE(AMOUNT value) {
        this.estimatedrevenue = value;
    }

    /**
     * Gets the value of the region property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getREGION() {
        return region;
    }

    /**
     * Sets the value of the region property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setREGION(TYPE_Type value) {
        this.region = value;
    }

    /**
     * Gets the value of the regionid property.
     * 
     * @return
     *     possible object is
     *     {@link REGIONID_Type }
     *     
     */
    public REGIONID_Type getREGIONID() {
        return regionid;
    }

    /**
     * Sets the value of the regionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link REGIONID_Type }
     *     
     */
    public void setREGIONID(REGIONID_Type value) {
        this.regionid = value;
    }

    /**
     * Gets the value of the primaryuse property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getPRIMARYUSE() {
        return primaryuse;
    }

    /**
     * Sets the value of the primaryuse property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setPRIMARYUSE(TYPE_Type value) {
        this.primaryuse = value;
    }

    /**
     * Gets the value of the yearbuilt property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getYEARBUILT() {
        return yearbuilt;
    }

    /**
     * Sets the value of the yearbuilt property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setYEARBUILT(QUANTITY value) {
        this.yearbuilt = value;
    }

    /**
     * Gets the value of the servicelife property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSERVICELIFE() {
        return servicelife;
    }

    /**
     * Sets the value of the servicelife property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSERVICELIFE(QUANTITY value) {
        this.servicelife = value;
    }

    /**
     * Gets the value of the energystareligible property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYSTARELIGIBLE() {
        return energystareligible;
    }

    /**
     * Sets the value of the energystareligible property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYSTARELIGIBLE(String value) {
        this.energystareligible = value;
    }

}
